pub struct CountdownTimer { /* private fields */ }Expand description
Hardware timers
Implementations
Sourceimpl CountdownTimer
impl CountdownTimer
Sourcepub fn new<Tim>(_tim: Tim, clks: &Clocks) -> CountdownTimerwhere
Tim: TimInstance,
Available on crate feature vor4x only.
pub fn new<Tim>(_tim: Tim, clks: &Clocks) -> CountdownTimerwhere
Tim: TimInstance,
vor4x only.Create a countdown timer structure for a given TIM peripheral.
This does not enable the timer. You can use the Self::load, Self::start, Self::enable_interrupt and Self::enable API to set up and configure the countdown timer.
pub fn perid(&self) -> u32
pub fn enable(&mut self)
pub fn disable(&mut self)
pub fn enable_interrupt(&mut self, enable_in_nvic: bool)
vor4x only.Sourcepub fn disable_interrupt(&mut self)
pub fn disable_interrupt(&mut self)
This function only clears the interrupt enable bit.
It does not mask the interrupt in the NVIC or un-route the IRQ.
Sourcepub fn start(&mut self, frequency: impl Into<Rate<u32, 1, 1>>)
pub fn start(&mut self, frequency: impl Into<Rate<u32, 1, 1>>)
Calls Self::load to configure the specified frequency and then calls Self::enable.
Sourcepub fn wait(&mut self) -> Result<(), Error<Infallible>>
pub fn wait(&mut self) -> Result<(), Error<Infallible>>
Return Ok if the timer has wrapped. Peripheral will automatically clear the
flag and restart the time if configured correctly
Sourcepub fn load(&mut self, timeout: impl Into<Rate<u32, 1, 1>>)
pub fn load(&mut self, timeout: impl Into<Rate<u32, 1, 1>>)
Load the count down timer with a timeout but do not start it.
pub fn set_reload(&mut self, val: u32)
pub fn set_count(&mut self, val: u32)
pub fn counter(&self) -> u32
Sourcepub fn auto_disable(&mut self, enable: bool)
pub fn auto_disable(&mut self, enable: bool)
Disable the counter, setting both enable and active bit to 0
Sourcepub fn auto_deactivate(&mut self, enable: bool)
pub fn auto_deactivate(&mut self, enable: bool)
This option only applies when the Auto-Disable functionality is 0.
The active bit is changed to 0 when count reaches 0, but the counter stays enabled. When Auto-Disable is 1, Auto-Deactivate is implied
Sourcepub fn cascade_control(&mut self, ctrl: CascadeControl)
pub fn cascade_control(&mut self, ctrl: CascadeControl)
Configure the cascade parameters
pub fn cascade_source( &mut self, cascade_index: CascadeSelect, src: CascadeSource, ) -> Result<(), InvalidCascadeSourceId>
pub fn curr_freq(&self) -> Rate<u32, 1, 1>
Sourcepub fn stop_with_clock_disable(self)
pub fn stop_with_clock_disable(self)
Disables the TIM and the dedicated TIM clock.